==> nextcloud-21.0.5.tgz: nextcloud/apps/twofactor_backupcodes/l10n/it.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Hai creato codici di backup a due fattori per il tuo account",
    "Second-factor backup codes" : "Codici di backup con secondo fattore",
    "Generate backup codes" : "Genera i codici di backup",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Hai abilitato l'autenticazione a due fattori, ma non hai ancora generato i codici di backup. Sono necessari per recuperare l'accesso al tuo account nel caso in cui tu perda l'accesso al secondo fattore.",
    "Backup code" : "Codice di backup",
    "Use backup code" : "Usa il codice di backup",
    "Two factor backup codes" : "Codici di backup a due fattori",
    "A two-factor auth backup codes provider" : "Un fornitore di codici di backup per l'autenticazione a due fattori",
    "Backup codes have been generated. {used} of {total} codes have been used." : "I codici di backup sono stati generali. {used} di {total} codici sono stati utilizzati.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Questi sono i tuoi codici di backup. Salvali e/o stampali poiché non potrai più leggerli successivamente",
    "Save backup codes" : "Salva i codici di backup",
    "Print backup codes" : "Stampa i codici di backup",
    "Regenerate backup codes" : "Rigenera i codici di backup",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Se rigeneri i codici di backup, invaliderai automaticamente i vecchi codici.",
    "An error occurred while generating your backup codes" : "Si è verificato un errore durante la generazione dei tuoi codici di backup",
    "{name} backup codes" : "Codici di backup di {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Usa uno dei codici di backup che hai salvato quando configuri l'autenticazione a due fattori.",
    "Submit" : "Invia"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.4.tgz: nextcloud/apps/twofactor_backupcodes/l10n/it.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Hai creato codici di backup a due fattori per il tuo account",
    "Second-factor backup codes" : "Codici di backup con secondo fattore",
    "Generate backup codes" : "Genera i codici di backup",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Hai abilitato l'autenticazione a due fattori, ma non hai ancora generato i codici di backup. Sono necessari per recuperare l'accesso al tuo account nel caso in cui tu perda l'accesso al secondo fattore.",
    "Backup code" : "Codice di backup",
    "Use backup code" : "Usa il codice di backup",
    "Two factor backup codes" : "Codici di backup a due fattori",
    "A two-factor auth backup codes provider" : "Un fornitore di codici di backup per l'autenticazione a due fattori",
    "Backup codes have been generated. {used} of {total} codes have been used." : "I codici di backup sono stati generali. {used} di {total} codici sono stati utilizzati.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Questi sono i tuoi codici di backup. Salvali e/o stampali poiché non potrai più leggerli successivamente",
    "Save backup codes" : "Salva i codici di backup",
    "Print backup codes" : "Stampa i codici di backup",
    "Regenerate backup codes" : "Rigenera i codici di backup",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Se rigeneri i codici di backup, invaliderai automaticamente i vecchi codici.",
    "An error occurred while generating your backup codes" : "Si è verificato un errore durante la generazione dei tuoi codici di backup",
    "{name} backup codes" : "Codici di backup di {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Usa uno dei codici di backup che hai salvato quando configuri l'autenticazione a due fattori.",
    "Submit" : "Invia"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
